NOCChainIssuer class abstract

Interface to implement custom operational credentials issuer (NOC chain generation).

Constructors

NOCChainIssuer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onNOCChainGenerationNeeded(String? onNOCChainGenerationCompleteHandle, CSRInfo csrInfo, AttestationInfo attestationInfo) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited