ChipDeviceController class
Methods
-
call(String method, dynamic arguments)
→ dynamic
-
override
-
connectedDevice(int nodeId, ConnectedDeviceCallback callback, {Object? connectContext})
→ Future<void>
-
-
continueCommissioning(int devicePtr, bool ignoreAttestationFailure)
→ Future<void>
-
This function instructs the commissioner to proceed to the next stage of commissioning after
attestation is reported.
-
deleteDeviceController()
→ Future<void>
-
-
destroy()
→ void
-
-
getFabricIndex()
→ Future<int?>
-
-
invoke(InvokeCallback callback, int nodeId, InvokeElement invokeElement, {Object? connectContext, int timedRequestTimeoutMs = 0, int imTimeoutMs = 0})
→ Future<void>
-
-
match(String method, dynamic arguments)
→ bool
-
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onNOCChainGeneration(ControllerParams params, {String? onNOCChainGenerationCompleteHandle})
→ Future<int>
-
When a NOCChainIssuer is set for this controller, then onNOCChainGenerationNeeded will be
called when the NOC CSR needs to be signed. This allows for custom credentials issuer
implementations, for example, when a proprietary cloud API will perform the CSR signing.
-
openPairingWindowWithPIN(Object connectContext, int duration, int discriminator, int setupPIN, OpenCommissioningCallback callback)
→ Future<bool>
-
-
pairDevice(int deviceId, int? connId, int? setupPincode, String? onboardingPayload, Uint8List? csrNonce, NetworkCredentials networkCredentials, {DeviceAttestationDelegate? attestationDelegate, CompletionListener? completionListener, int failSafeExpiryTimeoutSecs = 60, String displayName = 'Flutter Matter', String ecosystemName = 'FlutterEcosystem'})
→ Future<void>
-
when
attestationDelegate notnull, failSafeExpiryTimeoutSecs efficient
IOS must use onboardingPayload
-
publicKeyFromCSR(Uint8List csr)
→ Future<Uint8List>
-
Extract the public key from the given PKCS#10 certificate signing request. This is the public
key that a certificate issued in response to the request would need to have.
-
read(int nodeId, ReportCallback callback, List<ChipAttributePath>? attributePaths, List<ChipEventPath>? eventPaths, List<DataVersionFilter>? dataVersionFilters, bool isFabricFiltered, int imTimeoutMs, int eventMin, {Object? connectContext})
→ Future<void>
-
-
releaseConnectContext(Object connectContext)
→ Future<void>
-
-
setNocChainIssuer(NOCChainIssuer nocChainIssuer)
→ Future<void>
-
Sets this DeviceController to use the given issuer for issuing operational certs and verifying
the DAC. By default, the DeviceController uses an internal, OperationalCredentialsDelegate
-
stopDevicePairing(int deviceId)
→ Future<void>
-
-
subscribe(int nodeId, SubscriptionCallback callback, List<ChipAttributePath>? attributePaths, List<ChipEventPath>? eventPaths, int minInterval, int maxInterval, bool keepSubscriptions, bool isFabricFiltered, int imTimeoutMs, int eventMin, {Object? connectContext})
→ Future<void>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
unSubscription(int fabricIndex, int nodeId, int subscriptionId)
→ Future<bool>
-
-
write(int nodeId, WriteAttributesCallback callback, List<AttributeWriteRequest> attributeList, int timedRequestTimeoutMs, int imTimeoutMs, {Object? connectContext})
→ Future<void>
-